# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelUserInputValidationResponse(Model):
    """Model user input validation response (model.UserInputValidationResponse)

    Properties:
        valid: (valid) REQUIRED bool

        message: (message) OPTIONAL str
    """

    # region fields

    valid: bool  # REQUIRED
    message: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_valid(self, value: bool) -> ModelUserInputValidationResponse:
        self.valid = value
        return self

    def with_message(self, value: str) -> ModelUserInputValidationResponse:
        self.message = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "valid"):
            result["valid"] = bool(self.valid)
        elif include_empty:
            result["valid"] = False
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, valid: bool, message: Optional[str] = None, **kwargs
    ) -> ModelUserInputValidationResponse:
        instance = cls()
        instance.valid = valid
        if message is not None:
            instance.message = message
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelUserInputValidationResponse:
        instance = cls()
        if not dict_:
            return instance
        if "valid" in dict_ and dict_["valid"] is not None:
            instance.valid = bool(dict_["valid"])
        elif include_empty:
            instance.valid = False
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelUserInputValidationResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelUserInputValidationResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelUserInputValidationResponse,
        List[ModelUserInputValidationResponse],
        Dict[Any, ModelUserInputValidationResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "valid": "valid",
            "message": "message",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "valid": True,
            "message": False,
        }

    # endregion static methods



# Copyright (c) 2024 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: errors.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Iam Service

from accelbyte_py_sdk.core import ApiError

ERROR_422 = ApiError(code="422", message="request is unprocessable")
ERROR_10130 = ApiError(code="10130", message="user under age")
ERROR_10131 = ApiError(code="10131", message="invalid date of birth")
ERROR_10132 = ApiError(code="10132", message="invalid email address")
ERROR_10133 = ApiError(code="10133", message="email already used")
ERROR_10136 = ApiError(
    code="10136", message="code is either been used or not valid anymore"
)
ERROR_10137 = ApiError(code="10137", message="code is expired")
ERROR_10138 = ApiError(code="10138", message="code not match")
ERROR_10139 = ApiError(code="10139", message="platform account not found")
ERROR_10140 = ApiError(code="10140", message="user verified")
ERROR_10141 = ApiError(code="10141", message="email verified")
ERROR_10142 = ApiError(
    code="10142", message="new password cannot be same with original"
)
ERROR_10143 = ApiError(code="10143", message="password not match")
ERROR_10144 = ApiError(code="10144", message="user has no bans")
ERROR_10145 = ApiError(
    code="10145", message="disallow game access publisher user's ban"
)
ERROR_10146 = ApiError(code="10146", message="userID not match")
ERROR_10148 = ApiError(
    code="10148", message="verification code context doesn't match the required context"
)
ERROR_10149 = ApiError(code="10149", message="verification contact type doesn't match")
ERROR_10152 = ApiError(code="10152", message="verification code not found")
ERROR_10153 = ApiError(code="10153", message="user exist")
ERROR_10154 = ApiError(code="10154", message="country not found")
ERROR_10155 = ApiError(code="10155", message="country is not defined")
ERROR_10156 = ApiError(code="10156", message="role not found")
ERROR_10157 = ApiError(code="10157", message="specified role is not admin role")
ERROR_10158 = ApiError(code="10158", message="ban not found")
ERROR_10159 = ApiError(code="10159", message="operator is not a role manager")
ERROR_10160 = ApiError(code="10160", message="user already has the role")
ERROR_10161 = ApiError(code="10161", message="user already the role member")
ERROR_10162 = ApiError(code="10162", message="invalid verification")
ERROR_10163 = ApiError(
    code="10163", message="platform is already linked with the user account"
)
ERROR_10169 = ApiError(code="10169", message="age restriction not found")
ERROR_10170 = ApiError(code="10170", message="account is already a full account")
ERROR_10171 = ApiError(code="10171", message="email address not found")
ERROR_10172 = ApiError(
    code="10172", message="platform user is already linked with the account"
)
ERROR_10173 = ApiError(
    code="10173", message="platform is already linked with another user account"
)
ERROR_10174 = ApiError(code="10174", message="platform client not found")
ERROR_10175 = ApiError(code="10175", message="third party credential not found")
ERROR_10177 = ApiError(code="10177", message="username already used")
ERROR_10180 = ApiError(code="10180", message="admin invitation not found or expired")
ERROR_10182 = ApiError(
    code="10182", message="given namespace cannot be assigned to the role"
)
ERROR_10183 = ApiError(code="10183", message="unprocessable entity")
ERROR_10185 = ApiError(code="10185", message="publisher namespace not allowed")
ERROR_10188 = ApiError(code="10188", message="input validation field not found")
ERROR_10189 = ApiError(code="10189", message="invalid factor")
ERROR_10190 = ApiError(code="10190", message="auth secret key expired")
ERROR_10191 = ApiError(code="10191", message="email address not verified")
ERROR_10192 = ApiError(code="10192", message="factor not enabled")
ERROR_10193 = ApiError(code="10193", message="mfa not enabled")
ERROR_10194 = ApiError(code="10194", message="factor already enabled")
ERROR_10195 = ApiError(code="10195", message="no valid backup code found")
ERROR_10200 = ApiError(
    code="10200", message="link to a different platform account is not allowed"
)
ERROR_10202 = ApiError(code="10202", message="active device ban config already exists")
ERROR_10204 = ApiError(code="10204", message="device can not be banned")
ERROR_10207 = ApiError(code="10207", message="user namespace is not available")
ERROR_10208 = ApiError(code="10208", message="platform token expired")
ERROR_10213 = ApiError(code="10213", message="country is blocked")
ERROR_10215 = ApiError(code="10215", message="Simultaneous ticket is required")
ERROR_10216 = ApiError(code="10216", message="Native ticket is required")
ERROR_10217 = ApiError(
    code="10217",
    message="Native ticket's account linked AGS account has different linking history with input simultaneous ticket's",
)
ERROR_10218 = ApiError(
    code="10218",
    message="Simultaneous ticket's account linked AGS account has different linking history with input native ticket's",
)
ERROR_10219 = ApiError(
    code="10219",
    message="Native ticket's account linked AGS is already linked simultaneous but different with the input simultaneous ticket's",
)
ERROR_10220 = ApiError(
    code="10220",
    message="Native ticket's account linked AGS account is different with the one which simultaneous ticket's linked to",
)
ERROR_10221 = ApiError(
    code="10221",
    message="Simultaneous ticket's account linked AGS is already linked native but different with the input native ticket's",
)
ERROR_10222 = ApiError(code="10222", message="unique display name already exists")
ERROR_10226 = ApiError(code="10226", message="third party platform is not supported")
ERROR_10228 = ApiError(code="10228", message="invalid mfa token")
ERROR_10229 = ApiError(code="10229", message="request body exceed max limitation")
ERROR_10235 = ApiError(code="10235", message="date of birth not allowed to update")
ERROR_10236 = ApiError(code="10236", message="username not allowed to update")
ERROR_10237 = ApiError(code="10237", message="display name not allowed to update")
ERROR_10238 = ApiError(code="10238", message="country not allowed to update")
ERROR_10240 = ApiError(code="10240", message="namespace is not game namespace")
ERROR_10364 = ApiError(code="10364", message="client exists")
ERROR_10365 = ApiError(code="10365", message="client not found")
ERROR_10456 = ApiError(code="10456", message="role not found")
ERROR_10457 = ApiError(code="10457", message="specified role is not admin role")
ERROR_10459 = ApiError(code="10459", message="operator is not a role manager")
ERROR_10466 = ApiError(code="10466", message="invalid role members")
ERROR_10467 = ApiError(code="10467", message="role has no manager")
ERROR_10468 = ApiError(code="10468", message="role manager exist")
ERROR_10469 = ApiError(code="10469", message="role member exist")
ERROR_10470 = ApiError(code="10470", message="role is empty")
ERROR_20000 = ApiError(code="20000", message="internal server error")
ERROR_20001 = ApiError(code="20001", message="unauthorized access")
ERROR_20002 = ApiError(code="20002", message="validation error")
ERROR_20003 = ApiError(code="20003", message="forbidden access")
ERROR_20007 = ApiError(code="20007", message="too many requests")
ERROR_20008 = ApiError(code="20008", message="user not found")
ERROR_20009 = ApiError(code="20009", message="request_conflict")
ERROR_20013 = ApiError(code="20013", message="insufficient permissions")
ERROR_20019 = ApiError(code="20019", message="unable to parse request body")
ERROR_20021 = ApiError(code="20021", message="invalid pagination parameter")
ERROR_20022 = ApiError(code="20022", message="token is not user token")
ERROR_20024 = ApiError(code="20024", message="not implemented")
ERROR_20025 = ApiError(code="20025", message="not a publisher user")
ERROR_1014001 = ApiError(code="1014001", message="unable to parse request body")
ERROR_1014002 = ApiError(code="1014002", message="user already exists")
ERROR_1014016 = ApiError(code="1014016", message="unable to parse request body")
ERROR_1014017 = ApiError(code="1014017", message="user not found")
ERROR_1014018 = ApiError(code="1014018", message="verification code not found")
ERROR_1014019 = ApiError(code="1014019", message="verification code already used")
ERROR_1014020 = ApiError(code="1014020", message="verification code invalid")
ERROR_1014021 = ApiError(code="1014021", message="verification code expired")
ERROR_1015073 = ApiError(code="1015073", message="new password same as old password")



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelDisableMFARequest(Model):
    """Model disable MFA request (model.DisableMFARequest)

    Properties:
        factor: (factor) OPTIONAL str

        mfa_token: (mfaToken) OPTIONAL str
    """

    # region fields

    factor: str  # OPTIONAL
    mfa_token: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_factor(self, value: str) -> ModelDisableMFARequest:
        self.factor = value
        return self

    def with_mfa_token(self, value: str) -> ModelDisableMFARequest:
        self.mfa_token = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "factor"):
            result["factor"] = str(self.factor)
        elif include_empty:
            result["factor"] = ""
        if hasattr(self, "mfa_token"):
            result["mfaToken"] = str(self.mfa_token)
        elif include_empty:
            result["mfaToken"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, factor: Optional[str] = None, mfa_token: Optional[str] = None, **kwargs
    ) -> ModelDisableMFARequest:
        instance = cls()
        if factor is not None:
            instance.factor = factor
        if mfa_token is not None:
            instance.mfa_token = mfa_token
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelDisableMFARequest:
        instance = cls()
        if not dict_:
            return instance
        if "factor" in dict_ and dict_["factor"] is not None:
            instance.factor = str(dict_["factor"])
        elif include_empty:
            instance.factor = ""
        if "mfaToken" in dict_ and dict_["mfaToken"] is not None:
            instance.mfa_token = str(dict_["mfaToken"])
        elif include_empty:
            instance.mfa_token = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelDisableMFARequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelDisableMFARequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelDisableMFARequest,
        List[ModelDisableMFARequest],
        Dict[Any, ModelDisableMFARequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "factor": "factor",
            "mfaToken": "mfa_token",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "factor": False,
            "mfaToken": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelUserStateResponseV3(Model):
    """Model user state response V3 (model.UserStateResponseV3)

    Properties:
        email_verified: (emailVerified) REQUIRED bool

        enabled: (enabled) REQUIRED bool

        full_account: (fullAccount) REQUIRED bool

        test_account: (testAccount) REQUIRED bool
    """

    # region fields

    email_verified: bool  # REQUIRED
    enabled: bool  # REQUIRED
    full_account: bool  # REQUIRED
    test_account: bool  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_email_verified(self, value: bool) -> ModelUserStateResponseV3:
        self.email_verified = value
        return self

    def with_enabled(self, value: bool) -> ModelUserStateResponseV3:
        self.enabled = value
        return self

    def with_full_account(self, value: bool) -> ModelUserStateResponseV3:
        self.full_account = value
        return self

    def with_test_account(self, value: bool) -> ModelUserStateResponseV3:
        self.test_account = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "email_verified"):
            result["emailVerified"] = bool(self.email_verified)
        elif include_empty:
            result["emailVerified"] = False
        if hasattr(self, "enabled"):
            result["enabled"] = bool(self.enabled)
        elif include_empty:
            result["enabled"] = False
        if hasattr(self, "full_account"):
            result["fullAccount"] = bool(self.full_account)
        elif include_empty:
            result["fullAccount"] = False
        if hasattr(self, "test_account"):
            result["testAccount"] = bool(self.test_account)
        elif include_empty:
            result["testAccount"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        email_verified: bool,
        enabled: bool,
        full_account: bool,
        test_account: bool,
        **kwargs,
    ) -> ModelUserStateResponseV3:
        instance = cls()
        instance.email_verified = email_verified
        instance.enabled = enabled
        instance.full_account = full_account
        instance.test_account = test_account
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelUserStateResponseV3:
        instance = cls()
        if not dict_:
            return instance
        if "emailVerified" in dict_ and dict_["emailVerified"] is not None:
            instance.email_verified = bool(dict_["emailVerified"])
        elif include_empty:
            instance.email_verified = False
        if "enabled" in dict_ and dict_["enabled"] is not None:
            instance.enabled = bool(dict_["enabled"])
        elif include_empty:
            instance.enabled = False
        if "fullAccount" in dict_ and dict_["fullAccount"] is not None:
            instance.full_account = bool(dict_["fullAccount"])
        elif include_empty:
            instance.full_account = False
        if "testAccount" in dict_ and dict_["testAccount"] is not None:
            instance.test_account = bool(dict_["testAccount"])
        elif include_empty:
            instance.test_account = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelUserStateResponseV3]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelUserStateResponseV3]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelUserStateResponseV3,
        List[ModelUserStateResponseV3],
        Dict[Any, ModelUserStateResponseV3],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "emailVerified": "email_verified",
            "enabled": "enabled",
            "fullAccount": "full_account",
            "testAccount": "test_account",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "emailVerified": True,
            "enabled": True,
            "fullAccount": True,
            "testAccount": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class OauthmodelUserBan(Model):
    """Oauthmodel user ban (oauthmodel.UserBan)

    Properties:
        comment: (comment) REQUIRED str

        end_date: (endDate) REQUIRED int

        reason: (reason) REQUIRED str
    """

    # region fields

    comment: str  # REQUIRED
    end_date: int  # REQUIRED
    reason: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_comment(self, value: str) -> OauthmodelUserBan:
        self.comment = value
        return self

    def with_end_date(self, value: int) -> OauthmodelUserBan:
        self.end_date = value
        return self

    def with_reason(self, value: str) -> OauthmodelUserBan:
        self.reason = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "comment"):
            result["comment"] = str(self.comment)
        elif include_empty:
            result["comment"] = ""
        if hasattr(self, "end_date"):
            result["endDate"] = int(self.end_date)
        elif include_empty:
            result["endDate"] = 0
        if hasattr(self, "reason"):
            result["reason"] = str(self.reason)
        elif include_empty:
            result["reason"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, comment: str, end_date: int, reason: str, **kwargs
    ) -> OauthmodelUserBan:
        instance = cls()
        instance.comment = comment
        instance.end_date = end_date
        instance.reason = reason
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> OauthmodelUserBan:
        instance = cls()
        if not dict_:
            return instance
        if "comment" in dict_ and dict_["comment"] is not None:
            instance.comment = str(dict_["comment"])
        elif include_empty:
            instance.comment = ""
        if "endDate" in dict_ and dict_["endDate"] is not None:
            instance.end_date = int(dict_["endDate"])
        elif include_empty:
            instance.end_date = 0
        if "reason" in dict_ and dict_["reason"] is not None:
            instance.reason = str(dict_["reason"])
        elif include_empty:
            instance.reason = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, OauthmodelUserBan]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[OauthmodelUserBan]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        OauthmodelUserBan, List[OauthmodelUserBan], Dict[Any, OauthmodelUserBan]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "comment": "comment",
            "endDate": "end_date",
            "reason": "reason",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "comment": True,
            "endDate": True,
            "reason": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelFieldUpdateAllowStatus(Model):
    """Model field update allow status (model.FieldUpdateAllowStatus)

    Properties:
        field: (field) REQUIRED str

        type_: (type) REQUIRED str

        next_available_edit_time: (nextAvailableEditTime) OPTIONAL int

        remaining_time_in_seconds: (remainingTimeInSeconds) OPTIONAL int
    """

    # region fields

    field: str  # REQUIRED
    type_: str  # REQUIRED
    next_available_edit_time: int  # OPTIONAL
    remaining_time_in_seconds: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_field(self, value: str) -> ModelFieldUpdateAllowStatus:
        self.field = value
        return self

    def with_type(self, value: str) -> ModelFieldUpdateAllowStatus:
        self.type_ = value
        return self

    def with_next_available_edit_time(self, value: int) -> ModelFieldUpdateAllowStatus:
        self.next_available_edit_time = value
        return self

    def with_remaining_time_in_seconds(self, value: int) -> ModelFieldUpdateAllowStatus:
        self.remaining_time_in_seconds = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "field"):
            result["field"] = str(self.field)
        elif include_empty:
            result["field"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = ""
        if hasattr(self, "next_available_edit_time"):
            result["nextAvailableEditTime"] = int(self.next_available_edit_time)
        elif include_empty:
            result["nextAvailableEditTime"] = 0
        if hasattr(self, "remaining_time_in_seconds"):
            result["remainingTimeInSeconds"] = int(self.remaining_time_in_seconds)
        elif include_empty:
            result["remainingTimeInSeconds"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        field: str,
        type_: str,
        next_available_edit_time: Optional[int] = None,
        remaining_time_in_seconds: Optional[int] = None,
        **kwargs,
    ) -> ModelFieldUpdateAllowStatus:
        instance = cls()
        instance.field = field
        instance.type_ = type_
        if next_available_edit_time is not None:
            instance.next_available_edit_time = next_available_edit_time
        if remaining_time_in_seconds is not None:
            instance.remaining_time_in_seconds = remaining_time_in_seconds
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelFieldUpdateAllowStatus:
        instance = cls()
        if not dict_:
            return instance
        if "field" in dict_ and dict_["field"] is not None:
            instance.field = str(dict_["field"])
        elif include_empty:
            instance.field = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = ""
        if (
            "nextAvailableEditTime" in dict_
            and dict_["nextAvailableEditTime"] is not None
        ):
            instance.next_available_edit_time = int(dict_["nextAvailableEditTime"])
        elif include_empty:
            instance.next_available_edit_time = 0
        if (
            "remainingTimeInSeconds" in dict_
            and dict_["remainingTimeInSeconds"] is not None
        ):
            instance.remaining_time_in_seconds = int(dict_["remainingTimeInSeconds"])
        elif include_empty:
            instance.remaining_time_in_seconds = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelFieldUpdateAllowStatus]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelFieldUpdateAllowStatus]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelFieldUpdateAllowStatus,
        List[ModelFieldUpdateAllowStatus],
        Dict[Any, ModelFieldUpdateAllowStatus],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "field": "field",
            "type": "type_",
            "nextAvailableEditTime": "next_available_edit_time",
            "remainingTimeInSeconds": "remaining_time_in_seconds",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "field": True,
            "type": True,
            "nextAvailableEditTime": False,
            "remainingTimeInSeconds": False,
        }

    # endregion static methods
